==> jdk-11.0.7_linux-x64_bin.tar.gz: jdk.charsets/sun/nio/cs/ext/IBM875.java <==
/*
 * Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */

package sun.nio.cs.ext;

import java.nio.charset.Charset;
import java.nio.charset.CharsetDecoder;
import java.nio.charset.CharsetEncoder;
import sun.nio.cs.StandardCharsets;
import sun.nio.cs.SingleByte;
import sun.nio.cs.HistoricallyNamedCharset;
import static sun.nio.cs.CharsetMapping.*;

public class IBM875 extends Charset implements HistoricallyNamedCharset
{
    public IBM875() {
        super("x-IBM875", ExtendedCharsets.aliasesFor("x-IBM875"));
    }

    public String historicalName() {
        return "Cp875";
    }

    public boolean contains(Charset cs) {
        return (cs instanceof IBM875);
    }

    public CharsetDecoder newDecoder() {
        return new SingleByte.Decoder(this, b2c, false);
    }

    public CharsetEncoder newEncoder() {
        return new SingleByte.Encoder(this, c2b, c2bIndex, false);
    }

    private final static String b2cTable = 
        "\u0385\u0061\u0062\u0063\u0064\u0065\u0066\u0067" +      // 0x80 - 0x87
        "\u0068\u0069\u03B1\u03B2\u03B3\u03B4\u03B5\u03B6" +      // 0x88 - 0x8f
        "\u00B0\u006A\u006B\u006C\u006D\u006E\u006F\u0070" +      // 0x90 - 0x97
        "\u0071\u0072\u03B7\u03B8\u03B9\u03BA\u03BB\u03BC" +      // 0x98 - 0x9f
        "\u00B4\u007E\u0073\u0074\u0075\u0076\u0077\u0078" +      // 0xa0 - 0xa7
        "\u0079\u007A\u03BD\u03BE\u03BF\u03C0\u03C1\u03C3" +      // 0xa8 - 0xaf
        "\u00A3\u03AC\u03AD\u03AE\u03CA\u03AF\u03CC\u03CD" +      // 0xb0 - 0xb7
        "\u03CB\u03CE\u03C2\u03C4\u03C5\u03C6\u03C7\u03C8" +      // 0xb8 - 0xbf
        "\u007B\u0041\u0042\u0043\u0044\u0045\u0046\u0047" +      // 0xc0 - 0xc7
        "\u0048\u0049\u00AD\u03C9\u0390\u03B0\u2018\u2015" +      // 0xc8 - 0xcf
        "\u007D\u004A\u004B\u004C\u004D\u004E\u004F\u0050" +      // 0xd0 - 0xd7
        "\u0051\u0052\u00B1\u00BD\uFFFD\u0387\u2019\u00A6" +      // 0xd8 - 0xdf
        "\\\uFFFD\u0053\u0054\u0055\u0056\u0057\u0058" +      // 0xe0 - 0xe7
        "\u0059\u005A\u00B2\u00A7\uFFFD\uFFFD\u00AB\u00AC" +      // 0xe8 - 0xef
        "\u0030\u0031\u0032\u0033\u0034\u0035\u0036\u0037" +      // 0xf0 - 0xf7
        "\u0038\u0039\u00B3\u00A9\uFFFD\uFFFD\u00BB\u009F" +      // 0xf8 - 0xff
        "\u0000\u0001\u0002\u0003\u009C\t\u0086\u007F" +      // 0x00 - 0x07
        "\u0097\u008D\u008E\u000B\f\r\u000E\u000F" +      // 0x08 - 0x0f
        "\u0010\u0011\u0012\u0013\u009D\n\b\u0087" +      // 0x10 - 0x17
        "\u0018\u0019\u0092\u008F\u001C\u001D\u001E\u001F" +      // 0x18 - 0x1f
        "\u0080\u0081\u0082\u0083\u0084\n\u0017\u001B" +      // 0x20 - 0x27
        "\u0088\u0089\u008A\u008B\u008C\u0005\u0006\u0007" +      // 0x28 - 0x2f
        "\u0090\u0091\u0016\u0093\u0094\u0095\u0096\u0004" +      // 0x30 - 0x37
        "\u0098\u0099\u009A\u009B\u0014\u0015\u009E\u001A" +      // 0x38 - 0x3f
        "\u0020\u0391\u0392\u0393\u0394\u0395\u0396\u0397" +      // 0x40 - 0x47
        "\u0398\u0399\u005B\u002E\u003C\u0028\u002B\u0021" +      // 0x48 - 0x4f
        "\u0026\u039A\u039B\u039C\u039D\u039E\u039F\u03A0" +      // 0x50 - 0x57
        "\u03A1\u03A3\u005D\u0024\u002A\u0029\u003B\u005E" +      // 0x58 - 0x5f
        "\u002D\u002F\u03A4\u03A5\u03A6\u03A7\u03A8\u03A9" +      // 0x60 - 0x67
        "\u03AA\u03AB\u007C\u002C\u0025\u005F\u003E\u003F" +      // 0x68 - 0x6f
        "\u00A8\u0386\u0388\u0389\u00A0\u038A\u038C\u038E" +      // 0x70 - 0x77
        "\u038F\u0060\u003A\u0023\u0040\'\u003D\"" ;      // 0x78 - 0x7f


    private final static char[] b2c = b2cTable.toCharArray();
    private final static char[] c2b = new char[0x400];
    private final static char[] c2bIndex = new char[0x100];

    static {
        char[] b2cMap = b2c;
        char[] c2bNR = null;
        // remove non-roundtrip entries
        b2cMap = b2cTable.toCharArray();
        b2cMap[165] = UNMAPPABLE_DECODING;

        // non-roundtrip c2b only entries
        c2bNR = new char[2];
        c2bNR[0] = 0x15; c2bNR[1] = 0x85;

        SingleByte.initC2B(b2cMap, c2bNR, c2b, c2bIndex);
    }
}

==> jdk-21.0.7_linux-x64_bin.tar.gz: jdk.charsets/sun/nio/cs/ext/IBM875.java <==
/*
 * Copyright (c) 2008, 2021, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */

package sun.nio.cs.ext;

import java.nio.charset.Charset;
import java.nio.charset.CharsetDecoder;
import java.nio.charset.CharsetEncoder;
import sun.nio.cs.StandardCharsets;
import sun.nio.cs.SingleByte;
import sun.nio.cs.HistoricallyNamedCharset;
import static sun.nio.cs.CharsetMapping.*;

public class IBM875 extends Charset implements HistoricallyNamedCharset
{
    public IBM875() {
        super("x-IBM875", ExtendedCharsets.aliasesFor("x-IBM875"));
    }

    public String historicalName() {
        return "Cp875";
    }

    public boolean contains(Charset cs) {
        return (cs instanceof IBM875);
    }

    public CharsetDecoder newDecoder() {
        return new SingleByte.Decoder(this, Holder.b2c, false, false);
    }

    public CharsetEncoder newEncoder() {
        return new SingleByte.Encoder(this, Holder.c2b, Holder.c2bIndex, false);
    }

    private static class Holder {
        private static final String b2cTable = 
        "\u0385\u0061\u0062\u0063\u0064\u0065\u0066\u0067" +      // 0x80 - 0x87
        "\u0068\u0069\u03B1\u03B2\u03B3\u03B4\u03B5\u03B6" +      // 0x88 - 0x8f
        "\u00B0\u006A\u006B\u006C\u006D\u006E\u006F\u0070" +      // 0x90 - 0x97
        "\u0071\u0072\u03B7\u03B8\u03B9\u03BA\u03BB\u03BC" +      // 0x98 - 0x9f
        "\u00B4\u007E\u0073\u0074\u0075\u0076\u0077\u0078" +      // 0xa0 - 0xa7
        "\u0079\u007A\u03BD\u03BE\u03BF\u03C0\u03C1\u03C3" +      // 0xa8 - 0xaf
        "\u00A3\u03AC\u03AD\u03AE\u03CA\u03AF\u03CC\u03CD" +      // 0xb0 - 0xb7
        "\u03CB\u03CE\u03C2\u03C4\u03C5\u03C6\u03C7\u03C8" +      // 0xb8 - 0xbf
        "\u007B\u0041\u0042\u0043\u0044\u0045\u0046\u0047" +      // 0xc0 - 0xc7
        "\u0048\u0049\u00AD\u03C9\u0390\u03B0\u2018\u2015" +      // 0xc8 - 0xcf
        "\u007D\u004A\u004B\u004C\u004D\u004E\u004F\u0050" +      // 0xd0 - 0xd7
        "\u0051\u0052\u00B1\u00BD\uFFFD\u0387\u2019\u00A6" +      // 0xd8 - 0xdf
        "\\\uFFFD\u0053\u0054\u0055\u0056\u0057\u0058" +      // 0xe0 - 0xe7
        "\u0059\u005A\u00B2\u00A7\uFFFD\uFFFD\u00AB\u00AC" +      // 0xe8 - 0xef
        "\u0030\u0031\u0032\u0033\u0034\u0035\u0036\u0037" +      // 0xf0 - 0xf7
        "\u0038\u0039\u00B3\u00A9\uFFFD\uFFFD\u00BB\u009F" +      // 0xf8 - 0xff
        "\u0000\u0001\u0002\u0003\u009C\t\u0086\u007F" +      // 0x00 - 0x07
        "\u0097\u008D\u008E\u000B\f\r\u000E\u000F" +      // 0x08 - 0x0f
        "\u0010\u0011\u0012\u0013\u009D\n\b\u0087" +      // 0x10 - 0x17
        "\u0018\u0019\u0092\u008F\u001C\u001D\u001E\u001F" +      // 0x18 - 0x1f
        "\u0080\u0081\u0082\u0083\u0084\n\u0017\u001B" +      // 0x20 - 0x27
        "\u0088\u0089\u008A\u008B\u008C\u0005\u0006\u0007" +      // 0x28 - 0x2f
        "\u0090\u0091\u0016\u0093\u0094\u0095\u0096\u0004" +      // 0x30 - 0x37
        "\u0098\u0099\u009A\u009B\u0014\u0015\u009E\u001A" +      // 0x38 - 0x3f
        "\u0020\u0391\u0392\u0393\u0394\u0395\u0396\u0397" +      // 0x40 - 0x47
        "\u0398\u0399\u005B\u002E\u003C\u0028\u002B\u0021" +      // 0x48 - 0x4f
        "\u0026\u039A\u039B\u039C\u039D\u039E\u039F\u03A0" +      // 0x50 - 0x57
        "\u03A1\u03A3\u005D\u0024\u002A\u0029\u003B\u005E" +      // 0x58 - 0x5f
        "\u002D\u002F\u03A4\u03A5\u03A6\u03A7\u03A8\u03A9" +      // 0x60 - 0x67
        "\u03AA\u03AB\u007C\u002C\u0025\u005F\u003E\u003F" +      // 0x68 - 0x6f
        "\u00A8\u0386\u0388\u0389\u00A0\u038A\u038C\u038E" +      // 0x70 - 0x77
        "\u038F\u0060\u003A\u0023\u0040\'\u003D\"" ;      // 0x78 - 0x7f


        private static final char[] b2c = b2cTable.toCharArray();
        private static final char[] c2b = new char[0x400];
        private static final char[] c2bIndex = new char[0x100];

        static {
            char[] b2cMap = b2c;
            char[] c2bNR = null;
            // remove non-roundtrip entries
        b2cMap = b2cTable.toCharArray();
        b2cMap[165] = UNMAPPABLE_DECODING;

            // non-roundtrip c2b only entries
        c2bNR = new char[2];
        c2bNR[0] = 0x15; c2bNR[1] = 0x85;

            SingleByte.initC2B(b2cMap, c2bNR, c2b, c2bIndex);
        }
    }
}
